==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/DockManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { DockManagerLayout } from "./DockManagerLayout";
import { DockManagerPane } from "./DockManagerPane";
import { DockManagerPoint } from "./DockManagerPoint";
import { ContentPane } from "./ContentPane";
import { DockManagerShowHeaderIconOnHover_$type } from "./DockManagerShowHeaderIconOnHover";
import { DockManagerResourceStrings } from "./DockManagerResourceStrings";
import { LayoutChangeEventArgs } from "./LayoutChangeEventArgs";
/**
 * @hidden
 */
export let DockManager = /*@__PURE__*/ (() => {
    class DockManager extends BaseElement {
        constructor() {
            super(...arguments);
            this.layoutChange = null;
            this.i = new WCNativeHelper();
            this.o = null;
        }
        layoutChangeChanged() {
            if (this.layoutChange != null) {
                this.j.q("layoutChange", (a) => this.layoutChange(this, LayoutChangeEventArgs.b(this.b)), false);
            }
            else {
                this.j.t("layoutChange");
            }
        }
        get j() {
            return this.i;
        }
        get nativeElement() {
            return this.o;
        }
        set nativeElement(a) {
            this.o = a;
            this.i.n = this.o;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.j.l("layout", (a) => new DockManagerLayout());
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.j.u("layout", value_);
        }
        get c() {
            let ret_ = this.j.l("draggedPane", (a) => DockManagerPane.createFromNative(a));
            return ret_;
        }
        set c(a) {
            let value_ = a;
            this.j.u("draggedPane", value_);
        }
        get e() {
            let ret_ = this.j.l("dropPosition", (a) => new DockManagerPoint());
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.j.u("dropPosition", value_);
        }
        get a() {
            let ret_ = this.j.l("activePane", (a) => new ContentPane());
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.j.u("activePane", value_);
        }
        get m() {
            let ret_ = this.j.m("allowMaximize");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.j.u("allowMaximize", value_);
        }
        get g() {
            let ret_ = this.j.m("showHeaderIconOnHover");
            ret_ = enumGetBox(DockManagerShowHeaderIconOnHover_$type, EnumUtil.getEnumValue(DockManagerShowHeaderIconOnHover_$type, this.j.f(DockManagerShowHeaderIconOnHover_$type, ret_)));
            return EnumUtil.getEnumValue(DockManagerShowHeaderIconOnHover_$type, ret_);
        }
        set g(a) {
            let value_ = enumGetBox(DockManagerShowHeaderIconOnHover_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.j.u("showHeaderIconOnHover", value_);
        }
        get d() {
            let ret_ = this.j.l("maximizedPane", (a) => DockManagerPane.createFromNative(a));
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.j.u("maximizedPane", value_);
        }
        get f() {
            let ret_ = this.j.l("resourceStrings", (a) => new DockManagerResourceStrings());
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.j.u("resourceStrings", value_);
        }
        get k() {
            let ret_ = this.j.m("allowFloatingPanesResize");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.j.u("allowFloatingPanesResize", value_);
        }
        get n() {
            let ret_ = this.j.m("disableKeyboardNavigation");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.j.u("disableKeyboardNavigation", value_);
        }
        get l() {
            let ret_ = this.j.m("allowInnerDock");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.j.u("allowInnerDock", value_);
        }
        q(a) {
            this.nativeElement.focusPane(this.j.h(a));
        }
    }
    DockManager.$t = /*@__PURE__*/ markType(DockManager, 'DockManager', BaseElement.$);
    return DockManager;
})();

==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/DockManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { DockManagerLayout } from "./DockManagerLayout";
import { DockManagerPane } from "./DockManagerPane";
import { DockManagerPoint } from "./DockManagerPoint";
import { ContentPane } from "./ContentPane";
import { DockManagerShowHeaderIconOnHover_$type } from "./DockManagerShowHeaderIconOnHover";
import { DockManagerResourceStrings } from "./DockManagerResourceStrings";
import { LayoutChangeEventArgs } from "./LayoutChangeEventArgs";
/**
 * @hidden
 */
export let DockManager = /*@__PURE__*/ (() => {
    class DockManager extends BaseElement {
        constructor() {
            super(...arguments);
            this.layoutChange = null;
            this.i = new WCNativeHelper();
            this.o = null;
        }
        layoutChangeChanged() {
            if (this.layoutChange != null) {
                this.j.r("layoutChange", (a) => this.layoutChange(this, LayoutChangeEventArgs.b(this.b)), false);
            }
            else {
                this.j.u("layoutChange");
            }
        }
        get j() {
            return this.i;
        }
        get nativeElement() {
            return this.o;
        }
        set nativeElement(a) {
            this.o = a;
            this.i.o = this.o;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.j.m("layout", (a) => new DockManagerLayout());
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.j.v("layout", value_);
        }
        get c() {
            let ret_ = this.j.m("draggedPane", (a) => DockManagerPane.createFromNative(a));
            return ret_;
        }
        set c(a) {
            let value_ = a;
            this.j.v("draggedPane", value_);
        }
        get e() {
            let ret_ = this.j.m("dropPosition", (a) => new DockManagerPoint());
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.j.v("dropPosition", value_);
        }
        get a() {
            let ret_ = this.j.m("activePane", (a) => new ContentPane());
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.j.v("activePane", value_);
        }
        get m() {
            let ret_ = this.j.n("allowMaximize");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.j.v("allowMaximize", value_);
        }
        get g() {
            let ret_ = this.j.n("showHeaderIconOnHover");
            ret_ = enumGetBox(DockManagerShowHeaderIconOnHover_$type, EnumUtil.getEnumValue(DockManagerShowHeaderIconOnHover_$type, this.j.f(DockManagerShowHeaderIconOnHover_$type, ret_)));
            return EnumUtil.getEnumValue(DockManagerShowHeaderIconOnHover_$type, ret_);
        }
        set g(a) {
            let value_ = enumGetBox(DockManagerShowHeaderIconOnHover_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.j.v("showHeaderIconOnHover", value_);
        }
        get d() {
            let ret_ = this.j.m("maximizedPane", (a) => DockManagerPane.createFromNative(a));
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.j.v("maximizedPane", value_);
        }
        get f() {
            let ret_ = this.j.m("resourceStrings", (a) => new DockManagerResourceStrings());
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.j.v("resourceStrings", value_);
        }
        get k() {
            let ret_ = this.j.n("allowFloatingPanesResize");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.j.v("allowFloatingPanesResize", value_);
        }
        get n() {
            let ret_ = this.j.n("disableKeyboardNavigation");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.j.v("disableKeyboardNavigation", value_);
        }
        get l() {
            let ret_ = this.j.n("allowInnerDock");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.j.v("allowInnerDock", value_);
        }
        q(a) {
            this.nativeElement.focusPane(this.j.i(a));
        }
    }
    DockManager.$t = /*@__PURE__*/ markType(DockManager, 'DockManager', BaseElement.$);
    return DockManager;
})();
